/*
 * XIAO RP2040 test of OLED on the Seeeduino SIAO Expansion board
 * Patterned after the u8g2 library HelloWorld example
 * Except:
 *   OLED SCL, SDA are connected to XIAO RP2040 pin D5 and D4, which are
 *   connected to the RP2040 GIO pins P7 and P6.  P7 and P6 can not be connected
 *   to the RP2040 i2c0, which is for the Wire interface.  P7 and P6 can be
 *   connected to RP2040 i2c1 which is for the Wire1 interface, but the Seeed board
 *   package for the RP2040 is royally screwed up.  A way to make SCL and SDA on
 *   Arduino pins D5 and D5 is the following:
 *   
 *   Some changes to be made in the variants\pins_arduino.h file
 *   
 *
 *   On my Arduino 1.8.16 installation it's under my homw directory C:\users\davee:
 *     AppData\Local\Arduino15\packages\Seeeduino\hardware\rp2040\1.9.3\variants\Seeed_XIAO_RP2040
 *     
 *  Edit lines 61-65 in pins_arduino.h to look like this:
 *  #define SDA  (28u) // Change from (6u) davekw7x
 *  #define SCL  (29u) // Change from (7u) davekw7x
 *
 *  #define PIN_WIRE1_SDA  (6u) //  Change from (26u) davekw7x
 *  #define PIN_WIRE1_SCL  (7u) //  Change from (27u) davekw7x
 *
 *  Then note the board type in the u8x8 constructor below.  This uses Wire1 for the
 *  I2C stuff.
 *
 *
 *  davekw7x
 *  December, 2021
 */
 
// You must install the U8g2 library to get this
#include <U8x8lib.h>
 
U8X8_SSD1306_128X64_NONAME_2ND_HW_I2C u8x8(/* reset=*/ U8X8_PIN_NONE);

void setup(void) {
  u8x8.begin();
  // With default FlipMode(0), text can be read if the USB connector is on the left
  // With FlipMode(1), text can be read if the USB connector is on the right
  u8x8.setFlipMode(1);

  // There is no default font.  See ug2 library documentation
  // (or source code) to get an idea of available fonts
  u8x8.setFont(u8x8_font_chroma48medium8_r);
  // Start clean
  u8x8.clearDisplay();
}

// Hold a line to be displayed
char pbuf[17];

// Part of the test
uint8_t pass_number;

void loop(void) {
  // With an 8x8 font, there are eight lines.
  // Each line holds 16 characters
  //
  // First two arguments of drawString are the character
  // position on the line (0-15) and the line number (0-7)
  // Third argument is the string to be displayed.  With
  // default setup, strings longer than 16 chars wrap
  // around on the same line.
  //
  // Line 0 is the top line. Start at left end of display
  // Center this by counting spaces.  String has
  // 12 characters, so it needs two leading spaces
  // to center it
  u8x8.drawString(0, 0, "  Hello World!")
  ;
  // Line 1 is the next line: Exactly 16 characters
  u8x8.drawString(0, 1, "From XIAO RP2040");
  
  snprintf(pbuf, sizeof(pbuf), "Pass %3u", ++pass_number);
  // Center the next line horizontally. 
  uint8_t xstart = (16 - strlen(pbuf))  / 2;
  u8x8.drawString(xstart, 3, pbuf);

  // Now, sign off
  u8x8.drawString(0, 6, "Best regards,");
  u8x8.drawString(0, 7, "davekw7x");
  delay(1000);
  
} 
